# dt-extensions-models

<p>
  <a href="https://pypi.org/pypi/dt-extensions-models"><img alt="Package version" src="https://img.shields.io/pypi/v/dt-extensions-models?logo=python&logoColor=white&color=blue"></a>
  <a href="https://pypi.org/pypi/dt-extensions-models"><img alt="Supported python versions" src="https://img.shields.io/pypi/pyversions/dt-extensions-models?logo=python&logoColor=white"></a>
</p>

Helper library implementing best practices for strongly typed models and reporting metrics.

## Installation

```shell
pip install dt-extensions-models
```
